@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/aide.c,v 1.26 2002/05/31 12:47:07 rammer Exp $
+ * $Header: /cvsroot/aide/aide/src/aide.c,v 1.4 2003/11/28 15:03:58 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -116,7 +116,7 @@ int read_param(int argc,char**argv)
   };
 
   while(1){
-    option = getopt_long(argc, argv, "hV::vc:B:A:r:e:f:iCu", options, &i);
+    option = getopt_long(argc, argv, "hV::vc:B:A:r:iCuDE", options, &i);
     if(option==-1)
       break;
     switch(option)
@@ -294,6 +294,8 @@ void setdefaults_before_config()
   conf->db_out_url=NULL;
   conf->db_out=NULL;
 #ifdef WITH_ZLIB
+  conf->db_gzin=0;
+  conf->db_gznew=0;
   conf->gzip_dbout=0;
 #endif
 
@@ -472,6 +474,10 @@ int main(int argc,char**argv)
   }
   
   if((conf->do_configmd||conf->config_check)&& conf->confmd!=0){
+    /* The patch automatically adds a newline so will also have to add it. */
+    if(newlinelastinconfig==0){
+      mhash(conf->confmd,"\n",1);
+    };
     mhash(conf->confmd, NULL,0);
     dig=(byte*)malloc(sizeof(byte)*mhash_get_block_size(conf->confhmactype));
     mhash_deinit(conf->confmd,(void*)dig);
@@ -536,6 +542,14 @@ int main(int argc,char**argv)
       /* Then detailed list of changes */
       stat[0]=1;
       report_tree(conf->tree,4,stat);
+    } else {
+      printf("\nAIDE, version " AIDEVERSION "\n\n");
+      if(conf->action&DO_COMPARE) {
+        printf("### All files match AIDE database.  Looks okay!\n\n");
+      }
+      if(conf->action&DO_INIT) {
+        printf("### AIDE database initialized.\n\n");
+      }
     }
     db_close(conf);
     
@@ -546,7 +560,11 @@ int main(int argc,char**argv)
     if(conf->confmd){
       error(0,"Config checked. Use the following to patch your config file.\n");
       error(0,"0a1\n");
-      error(0,"> @@begin_config %s\n%ia%i\n> @@end_config\n",digstr,conf_lineno-2,conf_lineno);
+      if(newlinelastinconfig==1){
+	error(0,"> @@begin_config %s\n%ia%i\n> @@end_config\n",digstr,conf_lineno-1,conf_lineno+1);
+      }else {
+	error(0,"> @@begin_config %s\n%ia%i\n> @@end_config\n",digstr,conf_lineno,conf_lineno+2);
+      }
       free(dig);
       free(digstr);
     }
