@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/commandconf.c,v 1.30 2002/05/29 08:04:27 rammer Exp $
+ * $Header: /cvsroot/aide/aide/src/commandconf.c,v 1.2 2003/11/04 15:39:48 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -163,8 +163,10 @@ int commandconf(const char mode,const char* line)
     conf_scan_string(all);
     
     if(confparse()){
+      free(all);
       return RETFAIL;
     }
+    free(all);
     
     break;
   }
@@ -241,7 +243,7 @@ int db_input_wrapper(char* buf, int max_size, int db)
   int err=0;
   int* domd=0;
 #ifdef WITH_MHASH
-  MHASH* md;
+  MHASH* md=NULL;
   void* key=NULL;
   int keylen;
 #endif
@@ -385,6 +387,10 @@ int check_dboo(DB_FIELD a){
 
 void update_db_out_order(int attr)
 {
+  /* First we add those attributes that must be there */
+  if (check_dboo(db_linkname)==RETOK) {
+    conf->db_out_order[conf->db_out_size++]=db_linkname;
+  }
   if (check_dboo(db_attr)==RETOK) {
     conf->db_out_order[conf->db_out_size++]=db_attr;
   }
@@ -507,6 +513,7 @@ void putbackvariable(char* var)
   conf_put_token(v);
   conf_put_token("\n");
   free(v);
+  free(tmp);
 
 }
 
