@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/compare_db.c,v 1.9 2002/05/30 09:42:46 pablo Exp $
+ * $Header: /cvsroot/aide/aide/src/compare_db.c,v 1.2 2003/11/04 15:39:48 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -116,7 +116,7 @@ int compare_acl(acl_type* a1,acl_type* a2) {
 int compare_md_entries(byte* e1,byte* e2,int len)
 {
 
-  error(255,"Debug, compare_md_entreis %p %p\n",e1,e2);
+  error(255,"Debug, compare_md_entries %p %p\n",e1,e2);
 
   if(e1!=NULL && e2!=NULL){
     if(strncmp(e1,e2,len)!=0){
