@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/db.c,v 1.9 2002/05/29 08:04:27 rammer Exp $
+ * $Header: /cvsroot/aide/aide/src/db.c,v 1.2 2003/11/04 15:13:06 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -609,13 +609,6 @@ void free_db_line(db_line* dl)
   checked_free(dl->crc32b);
   checked_free(dl->gost);
   checked_free(dl->haval);
-  /*
-    Possible bug.
-    Maybe we shouldn't free filename and linkname...
-   */
-  checked_free(dl->filename);
-  checked_free(dl->linkname);
-  
 }
 const char* aide_key_5=CONFHMACKEY_05;
 const char* db_key_5=DBHMACKEY_05;
