@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/db_disk.c,v 1.13 2002/05/29 08:04:27 rammer Exp $
+ * $Header: /cvsroot/aide/aide/src/db_disk.c,v 1.2 2003/11/04 15:13:07 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -178,7 +178,8 @@ db_line* db_readline_disk(int db){
 
   /* root needs special handling */
   if(!root_handled){
-    fullname="/";
+    fullname=malloc(1+1);
+    strcpy(fullname,"/"); 
     add=check_rxtree(fullname,conf->tree,&attr);
     error(240,"%s match=%d, tree=%i, attr=%i\n",fullname, add,conf->tree,attr);
     
@@ -200,6 +201,8 @@ db_line* db_readline_disk(int db){
 	fil=NULL;
       }
     }
+    if (!add)
+      free(fullname);  
     root_handled=1;
   }
  recursion:
@@ -350,6 +353,38 @@ db_line* db_readline_disk(int db){
 	error(255,"New start_path=%s\n",start_path);
       
 	if (open_dir()==RETFAIL) {
+	  /* open_dir failed so we need to know why and print 
+	     an errormessage if needed.
+	     errno should still be the one from opendir() since it's global
+	  */ 
+	  if(errno == ENOENT && r->old_data != NULL &&
+	     r->sel_rx_lst==NULL && r->neg_rx_lst==NULL && 
+	     r->equ_rx_lst==NULL) {
+	    /* The path did not exist and there is old data for this node
+	       and there are no regexps for this node
+	       There is no new data for this node otherwise it would not
+	       come to this part of the code.
+	       So we don't print any error message.
+	       */	    
+	  }else {
+	    /* In any other case we print the message. */
+	    char* er=strerror(errno);
+	    if (er!=NULL) {
+	      error(5,"open_dir():%s: %s\n",er , start_path);
+	    } else {
+	      error(5,"open_dir():%i: %s\n",errno ,start_path);      
+	    }
+	    if(errno == ENOENT &&
+	       ((r->sel_rx_lst!=NULL || r->neg_rx_lst!=NULL || 
+	       r->equ_rx_lst!=NULL)||r->childs!=NULL)) {
+	      /* The dir did not exist and there are regexps referring to
+		 this node or there are children to this node. 
+		 The only way a nonexistant dirnode can have children is by 
+		 having rules referring to them.
+	       */
+	      error(5,"There are rules referring to non-existant directories!\n");
+	    }
+	  }
 	  r->checked|=NODE_TRAVERSE|NODE_CHECKED;
 	  r=r->parent;
 	  error(255,"dropping back to parent\n");
@@ -399,12 +434,15 @@ int  open_dir() {
   
   dirh=opendir(start_path);
   if (dirh==NULL) {
-    char* er=strerror(errno);
+    /* Errors should be printed here because then we get too many
+       errormessages. */
+    /*    char* er=strerror(errno);
     if (er!=NULL) {
       error(5,"open_dir():%s: %s\n",er , start_path);
     } else {
       error(5,"open_dir():%i: %s\n",errno ,start_path);      
     }
+    */
     return RETFAIL;
   }
   
