@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/db_file.c,v 1.18 2002/05/30 09:42:46 pablo Exp $
+ * $Header: /cvsroot/aide/aide/src/db_file.c,v 1.3 2003/08/18 13:06:30 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -95,7 +95,8 @@ int dofflush(void)
   int retval;
 #ifdef WITH_ZLIB
   if(conf->gzip_dbout){
-    retval=gzflush(conf->db_gzout,Z_SYNC_FLUSH);
+    /* Should not flush using gzip, it degrades compression */
+    retval=Z_OK;
   }else {
 #endif
     retval=fflush(conf->db_out); 
@@ -108,27 +109,23 @@ int dofflush(void)
 
 int dofprintf( const char* s,...)
 {
+  char buf[3];
   int retval;
   char* temp=NULL;
   va_list ap;
   
   va_start(ap,s);
-  temp=(char*)malloc(3);
-  if(temp==NULL){
-    error(0,"Unable to alloc %i bytes\n",3);
-    return -1;
-  }
-
-  retval=vsnprintf(temp,3,s,ap);
-  
-  free(temp);
+  retval=vsnprintf(buf,3,s,ap);
+  va_end(ap);
   
   temp=(char*)malloc(retval+2);
   if(temp==NULL){
     error(0,"Unable to alloc %i bytes\n",retval+2);
     return -1;
   }  
+  va_start(ap,s);
   retval=vsnprintf(temp,retval+1,s,ap);
+  va_end(ap);
   
 #ifdef WITH_MHASH
   if(conf->do_dbnewmd)
@@ -140,12 +137,13 @@ int dofprintf( const char* s,...)
     retval=gzwrite(conf->db_gzout,temp,retval);
   }else{
 #endif
+    va_start(ap,s);
     retval=vfprintf(conf->db_out,s,ap);
+    va_end(ap);
 #ifdef WITH_ZLIB
   }
 #endif
   free(temp);
-  va_end(ap);
 
   return retval;
 }
@@ -460,7 +458,9 @@ char** db_readline_file(int db){
 	i--;
 	break;
       }
-      
+      if(gotend_db){
+	return NULL;
+      }
       /*  */
 
       error(0,"Not enough parameters in db:%i. Trying to continue.\n",
@@ -515,6 +515,11 @@ char** db_readline_file(int db){
       break;
     }
 
+    case TEND_DBNOMD : {
+      gotend_db=1;
+      break;
+    }
+
     case TEOF : {
       if(gotend_db){
 	return NULL;
