@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti, Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/do_md.c,v 1.11 2002/05/31 12:47:07 rammer Exp $
+ * $Header: /cvsroot/aide/aide/src/do_md.c,v 1.1.1.1 2003/01/16 10:37:34 rammer Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -149,7 +149,7 @@ void calc_md(struct AIDE_STAT_TYPE* old_fs,db_line* line) {
     return;
   }
   
-  sres=fstat(filedes,&fs);
+  sres=AIDE_FSTAT_FUNC(filedes,&fs);
   
   if (stat_cmp(&fs,old_fs)==RETOK) {
     /*
