@@ -1,7 +1,7 @@
 /* aide, Advanced Intrusion Detection Environment
  *
  * Copyright (C) 1999,2000,2001,2002 Rami Lehti,Pablo Virolainen
- * $Header: /cvs-root-aide/aide2/src/gen_list.c,v 1.17 2002/05/30 09:53:52 pablo Exp $
+ * $Header: /cvsroot/aide/aide/src/gen_list.c,v 1.4 2003/11/04 15:39:48 rvdb Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -66,16 +66,31 @@ char* strrxtok(char* rx)
 {
   char*p=NULL;
   int i=0;
+  int j=1;
+  int last_backslash=0;
+  int lastslash_in_p=1;
 
-  /* This assumes that the first character is a slash */
-  int lastslash=1;
+  /* The following code assumes that the first character is a slash */
+  int lastslash=0;
+
+  p=(char*)malloc(sizeof(char)*strlen(rx)+1);
+  p[0]='/';
 
-  /* i=0 because we want to return at least the first slash */
   for(i=1;i<strlen(rx);i++){
     switch(rx[i])
       {
       case '/':
+	if(last_backslash){
+  		strncpy(p+j,rx+last_backslash+1,i-last_backslash);
+		j+=i-last_backslash;
+	}else{
+		strncpy(p+j,rx+lastslash+1,i-lastslash);
+		j+=i-lastslash;
+	}
+		
 	lastslash=i;
+	lastslash_in_p=j-1;
+
 	break;
       case '(':
       case '^':
@@ -83,21 +98,23 @@ char* strrxtok(char* rx)
       case '*':
       case '.':
       case '[':
-	/* FIXME: The '\\' character should be handled more gracefully. */
-	/* That is, if it is the only special character then */
-	/* The next character should be taken literally so */
-	/* that the search would be more efficient */
-      case '\\':
 	i=strlen(rx);
 	break;
+      case '\\':
+	last_backslash=i;
+	strncpy(p+j,rx+lastslash+1,i-lastslash);
+	j+=i-lastslash;
+	/* Skip the next character */
+	i++;
+	/* Don't copy the backslash */
+	j--;
+	break;
       default:
 	break;
       }
   }
 
-  p=(char*)malloc(sizeof(char)*lastslash+1);
-  strncpy(p,rx,lastslash);
-  p[lastslash]='\0';
+  p[lastslash_in_p]='\0';
 
 
   return p;
@@ -208,6 +225,7 @@ seltree* new_seltree_node(
 {
   seltree* node=NULL;
   seltree* parent=NULL;
+  char* tmprxtok = NULL;
 
   node=(seltree*)malloc(sizeof(seltree));
   node->childs=NULL;
@@ -223,19 +241,20 @@ seltree* new_seltree_node(
   copy_rule_ref(node,r);
 
   if(tree!=NULL){
+    tmprxtok = strrxtok(path);
     if(isrx){
-      parent=get_seltree_node(tree,strrxtok(path));
+      parent=get_seltree_node(tree,tmprxtok);
     }else {
       parent=get_seltree_node(tree,strlastslash(path));
     }      
     if(parent==NULL){
       if(isrx){
-	parent=new_seltree_node(tree,strrxtok(path),isrx,r);
+	parent=new_seltree_node(tree,tmprxtok,isrx,r);
       }else {
 	parent=new_seltree_node(tree,strlastslash(path),isrx,r);
       }
     }
-    
+    free(tmprxtok);
     parent->childs=list_append(parent->childs,(void*)node);
     node->parent=parent;
   }else {
@@ -311,6 +330,7 @@ void gen_seltree(list* rxlist,seltree* tree,char type)
     /* Data should not be free'ed because it's in rxc struct
      * and freeing is done if error occour.
      */
+      free(rxtok);
   }
 
 
@@ -369,6 +389,11 @@ list* add_file_to_list(list* listp,char*filename,int attr,int* addok)
   }
   
 #ifdef HAVE_USTAT
+  /* 
+   * This should not use ustat and should be implemented otherwise
+   * since ustat is not universally known function
+   * check find(1) for clues
+   */
   /*
     Here we should check if we need to add it..
    */  
@@ -1322,24 +1347,24 @@ void hsymlnk(db_line* line) {
       }
     }
     /*
-      Is this valid??
-      I think not.
+      Is this valid?? 
+      No, We should do this elsewhere.
+    */
+    /*    if(conf->symlinks_found==0){ 
+      int it=0; 
+      DB_FIELD dbtmp; 
+      DB_FIELD dbtmp2; 
+      dbtmp=conf->db_out_order[1]; 
+      conf->db_out_order[1]=db_linkname; 
+      for(it=2;it<conf->db_out_size;it++){ 
+      	dbtmp2=conf->db_out_order[it]; 
+      	conf->db_out_order[it]=dbtmp;
+      	dbtmp=dbtmp2;
+      } 
+      conf->db_out_order[conf->db_out_size++]=dbtmp; 
+      conf->symlinks_found=1; 
+    } 
     */
-    /*      if(conf->symlinks_found==0){ */
-    /*        int it=0; */
-    /*        DB_FIELD dbtmp; */
-    /*        DB_FIELD dbtmp2; */
-    /*        dbtmp=conf->db_out_order[1]; */
-    /*        conf->db_out_order[1]=db_linkname; */
-    /*        for(it=2;it<conf->db_out_size;it++){ */
-    /*  	dbtmp2=conf->db_out_order[it]; */
-    /*  	conf->db_out_order[it]=dbtmp; */
-    /*  	dbtmp=dbtmp2; */
-    /*        } */
-    /*        conf->db_out_order[conf->db_out_size++]=dbtmp; */
-    /*        conf->symlinks_found=1; */
-    /*      } */
-    
     line->linkname=(char*)malloc(_POSIX_PATH_MAX+1);
     if(line->linkname==NULL){
       error(0,_("malloc failed in add_file_to_list()\n"));
